@@ -1,4 +1,5 @@
 import json
+import logging
 import urllib.parse
 from time import sleep
 from typing import Generator
@@ -11,7 +12,10 @@ from tests.support.dtos import ConsumerStatus
 from tests.support.dtos import CurrentDestinationStatus
 from tests.support.dtos import MessageStatus
 
+logger = logging.getLogger(__name__)
+
 _queues_details_request_path = "/api/queues"
+_specific_queue_details_request_path = _queues_details_request_path + "/%2F/{queue_name}"
 _bindings_from_queue_request_path = _queues_details_request_path + "/%2F/{queue_name}/bindings"
 _get_message_from_queue_request_path = _queues_details_request_path + "/%2F/{queue_name}/get"
 _channels_details_request_path = "/api/channels"
@@ -20,25 +24,26 @@ _overview_request_path = "/api/overview"
 
 
 def current_queue_configuration(queue_name, host="localhost", port=15672) -> Optional[CurrentDestinationStatus]:
-    queues = _do_request(host, port, _queues_details_request_path)
-    results = list(filter(lambda v: v["name"] == queue_name, queues))
-    if len(results) == 1:
-        queue_details = results[0]
-        if queue_details.get("message_stats"):
-            message_stats = queue_details["message_stats"]
-            messages_dequeued = message_stats.get("deliver_get", 0)
-            messages_enqueued = message_stats["publish"]
-        else:
-            messages_dequeued = 0
-            messages_enqueued = None
+    result = _do_request(host, port, _specific_queue_details_request_path.format(queue_name=queue_name))
 
-        number_of_pending_messages = queue_details["messages"]
-        number_of_consumers = queue_details["consumers"]
+    logger.debug("RabbitMQ request result: %s", result)
+    if result.get("error"):
+        return None
 
-        return CurrentDestinationStatus(
-            number_of_pending_messages, number_of_consumers, messages_enqueued, messages_dequeued
-        )
-    return None
+    if result.get("message_stats"):
+        message_stats = result["message_stats"]
+        messages_dequeued = message_stats.get("deliver_get", 0)
+        messages_enqueued = message_stats.get("publish")
+    else:
+        messages_dequeued = 0
+        messages_enqueued = None
+
+    number_of_pending_messages = result["messages"]
+    number_of_consumers = result["consumers"]
+
+    return CurrentDestinationStatus(
+        number_of_pending_messages, number_of_consumers, messages_enqueued, messages_dequeued
+    )
 
 
 def current_topic_configuration(topic_name, host="localhost", port=15672) -> Optional[CurrentDestinationStatus]:
@@ -119,7 +124,7 @@ def get_broker_version(host="localhost", port=15672) -> str:
 
 
 def _do_request(host, port, request_path, do_post=False, body=None):
-    sleep(5)
+    sleep(2)
     session = requests.Session()
     session.mount("http://", HTTPAdapter(max_retries=3))
     address, auth = f"http://{host}:{port}{request_path}", ("guest", "guest")
